Learn R Programming

BlueCarbon (version 0.1.1)

estimate_h: Estimation of the thickness of the sample

Description

checks for space between samples and, if any, divide this space between the previous and next sample to return sample thickness without gaps in the core

Usage

estimate_h(
  df = NULL,
  core = "core",
  mind = "mind_corrected",
  maxd = "maxd_corrected"
)

Value

the initial data.frame with three additional columns:

  • emin (estimated minimum depth of the sample)

  • emax (estimated maximum depth of the sample)

  • h (estimated thickness of the sample)

Arguments

df

A data.frame with columns core, mind (minimum depth of the sample) and maxd (maximum depth of the sample)

core

Character Name of the column reporting core ID.

mind

Character Name of the column reporting the minimum depth of each sample.

maxd

Character Name of the column reporting the maximum depth of each sample.

Examples

Run this code
bluecarbon_decompact <- decompact(bluecarbon_data)
out <- estimate_h(bluecarbon_decompact)

Run the code above in your browser using DataLab