Learn R Programming

BlueCarbon (version 0.1.1)

estimate_seq_rate: Estimate the average organic carbon sequestration rate

Description

estimate the average organic carbon sequestration rate to the soil in a indicated time frame (by default last 100 years) from the organic carbon concentration and ages obtained from a age-depth or age-accumulated mass model

Usage

estimate_seq_rate(
  df = NULL,
  timeframe = 100,
  core = "core",
  mind = "mind_corrected",
  maxd = "maxd_corrected",
  dbd = "dbd",
  oc = "eoc",
  age = "age"
)

Value

data.frame with columns 'core', seq_rate_wc (organic carbon sequestration rates at the whole core), maxage (maximum age of the core), and seq_rate (average organic carbon sequestration rate at the indicated time frame)

Arguments

df

A data.frame with, at least, columns: core, mind (minimum depth of the sample), maxd (maximum depth of the sample), dbd (dry bulk density), oc (organic carbon %), age (age of the sample obtained from a age-depth or age-accumulated mass model)

timeframe

standardization time frame, by default 100 years

core

Character Name of the column reporting core ID.

mind

Character Name of the column reporting the minimum depth of each sample.

maxd

Character Name of the column reporting the maximum depth of each sample.

dbd

Character Name of the column reporting dry bulk density.

oc

Character Name of the column reporting organic carbon concentrations.

age

Character Name of the column reporting the age of each sample.

Examples

Run this code
bluecarbon_decompact <- decompact(bluecarbon_data)
oc <- estimate_oc(bluecarbon_decompact)
out <- estimate_seq_rate(oc[[1]])
head(out)

Run the code above in your browser using DataLab