powered by
checks for space between samples and, if any, divide this space between the previous and next sample to return sample thickness without gaps in the core
estimate_h( df = NULL, core = "core", mind = "mind_corrected", maxd = "maxd_corrected" )
the initial data.frame with three additional columns:
emin (estimated minimum depth of the sample)
emax (estimated maximum depth of the sample)
h (estimated thickness of the sample)
A data.frame with columns core, mind (minimum depth of the sample) and maxd (maximum depth of the sample)
Character Name of the column reporting core ID.
Character Name of the column reporting the minimum depth of each sample.
Character Name of the column reporting the maximum depth of each sample.
bluecarbon_decompact <- decompact(bluecarbon_data) out <- estimate_h(bluecarbon_decompact)
Run the code above in your browser using DataLab