- df
A data.frame with, at least, columns: core, mind (minimum depth of the sample),
maxd (maximum depth of the sample), dbd (dry bulk density), oc (organic carbon %),
age (age of the sample obtained from a age-depth or age-accumulated mass model)
- timeframe
standardization time frame, by default 100 years
- core
Character Name of the column reporting core ID.
- mind
Character Name of the column reporting the minimum depth of each sample.
- maxd
Character Name of the column reporting the maximum depth of each sample.
- dbd
Character Name of the column reporting dry bulk density.
- oc
Character Name of the column reporting organic carbon concentrations.
- age
Character Name of the column reporting the age of each sample.